nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Cfg

Struct Cfg 

#[repr(transparent)]
pub struct Cfg(pub u32);
SPI Configuration register

Tuple Fields

0: u32

Implementations

Source

impl Cfg

pub const fn enable(&self) -> bool

SPI enable.

pub const fn set_enable(&mut self, val: bool)

SPI enable.

pub const fn master(&self) -> Master

Master mode select.

pub const fn set_master(&mut self, val: Master)

Master mode select.

pub const fn lsbf(&self) -> Lsbf

LSB First mode enable.

pub const fn set_lsbf(&mut self, val: Lsbf)

LSB First mode enable.

pub const fn cpha(&self) -> Cpha

Clock Phase select.

pub const fn set_cpha(&mut self, val: Cpha)

Clock Phase select.

pub const fn cpol(&self) -> Cpol

Clock Polarity select.

pub const fn set_cpol(&mut self, val: Cpol)

Clock Polarity select.

pub const fn loop_(&self) -> bool

Loopback mode enable. Loopback mode applies only to Master mode, and connects transmit and receive data connected together to allow simple software testing.

pub const fn set_loop_(&mut self, val: bool)

Loopback mode enable. Loopback mode applies only to Master mode, and connects transmit and receive data connected together to allow simple software testing.

pub const fn spol0(&self) -> Spol0

SSEL0 Polarity select.

pub const fn set_spol0(&mut self, val: Spol0)

SSEL0 Polarity select.

pub const fn spol1(&self) -> Spol1

SSEL1 Polarity select.

pub const fn set_spol1(&mut self, val: Spol1)

SSEL1 Polarity select.

pub const fn spol2(&self) -> Spol2

SSEL2 Polarity select.

pub const fn set_spol2(&mut self, val: Spol2)

SSEL2 Polarity select.

pub const fn spol3(&self) -> Spol3

SSEL3 Polarity select.

pub const fn set_spol3(&mut self, val: Spol3)

SSEL3 Polarity select.