#[repr(transparent)]pub struct Div(pub u32);Expand description
SPI clock Divider
Tuple Fields
0: u32Implementations
Sourceimpl Div
impl Div
Sourcepub const fn divval(&self) -> u16
pub const fn divval(&self) -> u16
Rate divider value. Specifies how the Flexcomm clock (FCLK) is divided to produce the SPI clock rate in master mode. DIVVAL is -1 encoded such that the value 0 results in FCLK/1, the value 1 results in FCLK/2, up to the maximum possible divide value of 0xFFFF, which results in FCLK/65536.
Sourcepub const fn set_divval(&mut self, val: u16)
pub const fn set_divval(&mut self, val: u16)
Rate divider value. Specifies how the Flexcomm clock (FCLK) is divided to produce the SPI clock rate in master mode. DIVVAL is -1 encoded such that the value 0 results in FCLK/1, the value 1 results in FCLK/2, up to the maximum possible divide value of 0xFFFF, which results in FCLK/65536.