#[repr(transparent)]pub struct Fiford(pub u32);Expand description
FIFO read data.
Tuple Fields
0: u32Implementations
Sourceimpl Fiford
impl Fiford
Sourcepub const fn set_rxdata(&mut self, val: u16)
pub const fn set_rxdata(&mut self, val: u16)
Received data from the FIFO.
Sourcepub const fn rxssel0_n(&self) -> bool
pub const fn rxssel0_n(&self) -> bool
Slave Select for receive. This field allows the state of the SSEL0 pin to be saved along with received data. The value will reflect the SSEL0 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn set_rxssel0_n(&mut self, val: bool)
pub const fn set_rxssel0_n(&mut self, val: bool)
Slave Select for receive. This field allows the state of the SSEL0 pin to be saved along with received data. The value will reflect the SSEL0 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn rxssel1_n(&self) -> bool
pub const fn rxssel1_n(&self) -> bool
Slave Select for receive. This field allows the state of the SSEL1 pin to be saved along with received data. The value will reflect the SSEL1 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn set_rxssel1_n(&mut self, val: bool)
pub const fn set_rxssel1_n(&mut self, val: bool)
Slave Select for receive. This field allows the state of the SSEL1 pin to be saved along with received data. The value will reflect the SSEL1 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn rxssel2_n(&self) -> bool
pub const fn rxssel2_n(&self) -> bool
Slave Select for receive. This field allows the state of the SSEL2 pin to be saved along with received data. The value will reflect the SSEL2 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn set_rxssel2_n(&mut self, val: bool)
pub const fn set_rxssel2_n(&mut self, val: bool)
Slave Select for receive. This field allows the state of the SSEL2 pin to be saved along with received data. The value will reflect the SSEL2 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn rxssel3_n(&self) -> bool
pub const fn rxssel3_n(&self) -> bool
Slave Select for receive. This field allows the state of the SSEL3 pin to be saved along with received data. The value will reflect the SSEL3 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn set_rxssel3_n(&mut self, val: bool)
pub const fn set_rxssel3_n(&mut self, val: bool)
Slave Select for receive. This field allows the state of the SSEL3 pin to be saved along with received data. The value will reflect the SSEL3 pin for both master and slave operation. A zero indicates that a slave select is active. The actual polarity of each slave select pin is configured by the related SPOL bit in CFG.
Sourcepub const fn sot(&self) -> bool
pub const fn sot(&self) -> bool
Start of Transfer flag. This flag will be 1 if this is the first data after the SSELs went from deasserted to asserted (i.e., any previous transfer has ended). This information can be used to identify the first piece of data in cases where the transfer length is greater than 16 bits.
Sourcepub const fn set_sot(&mut self, val: bool)
pub const fn set_sot(&mut self, val: bool)
Start of Transfer flag. This flag will be 1 if this is the first data after the SSELs went from deasserted to asserted (i.e., any previous transfer has ended). This information can be used to identify the first piece of data in cases where the transfer length is greater than 16 bits.