nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Stat

Struct Stat 

#[repr(transparent)]
pub struct Stat(pub u32);
SPI Status. Some status flags can be cleared by writing a 1 to that bit position.

Tuple Fields

0: u32

Implementations

Source

impl Stat

pub const fn ssa(&self) -> bool

Slave Select Assert. This flag is set whenever any slave select transitions from deasserted to asserted, in both master and slave modes. This allows determining when the SPI transmit/receive functions become busy, and allows waking up the device from reduced power modes when a slave mode access begins. This flag is cleared by software.

pub const fn set_ssa(&mut self, val: bool)

Slave Select Assert. This flag is set whenever any slave select transitions from deasserted to asserted, in both master and slave modes. This allows determining when the SPI transmit/receive functions become busy, and allows waking up the device from reduced power modes when a slave mode access begins. This flag is cleared by software.

pub const fn ssd(&self) -> bool

Slave Select Deassert. This flag is set whenever any asserted slave selects transition to deasserted, in both master and slave modes. This allows determining when the SPI transmit/receive functions become idle. This flag is cleared by software.

pub const fn set_ssd(&mut self, val: bool)

Slave Select Deassert. This flag is set whenever any asserted slave selects transition to deasserted, in both master and slave modes. This allows determining when the SPI transmit/receive functions become idle. This flag is cleared by software.

pub const fn stalled(&self) -> bool

Stalled status flag. This indicates whether the SPI is currently in a stall condition.

pub const fn set_stalled(&mut self, val: bool)

Stalled status flag. This indicates whether the SPI is currently in a stall condition.

pub const fn endtransfer(&self) -> bool

End Transfer control bit. Software can set this bit to force an end to the current transfer when the transmitter finishes any activity already in progress, as if the EOT flag had been set prior to the last transmission. This capability is included to support cases where it is not known when transmit data is written that it will be the end of a transfer. The bit is cleared when the transmitter becomes idle as the transfer comes to an end. Forcing an end of transfer in this manner causes any specified FRAME_DELAY and TRANSFER_DELAY to be inserted.

pub const fn set_endtransfer(&mut self, val: bool)

End Transfer control bit. Software can set this bit to force an end to the current transfer when the transmitter finishes any activity already in progress, as if the EOT flag had been set prior to the last transmission. This capability is included to support cases where it is not known when transmit data is written that it will be the end of a transfer. The bit is cleared when the transmitter becomes idle as the transfer comes to an end. Forcing an end of transfer in this manner causes any specified FRAME_DELAY and TRANSFER_DELAY to be inserted.

pub const fn mstidle(&self) -> bool

Master idle status flag. This bit is 1 whenever the SPI master function is fully idle. This means that the transmit holding register is empty and the transmitter is not in the process of sending data.

pub const fn set_mstidle(&mut self, val: bool)

Master idle status flag. This bit is 1 whenever the SPI master function is fully idle. This means that the transmit holding register is empty and the transmitter is not in the process of sending data.