#[repr(transparent)]pub struct Cfg(pub u32);Expand description
SPI Configuration register
Tuple Fields
0: u32Implementations
Sourceimpl Cfg
impl Cfg
Sourcepub const fn set_enable(&mut self, val: bool)
pub const fn set_enable(&mut self, val: bool)
SPI enable.
Sourcepub const fn set_master(&mut self, val: Master)
pub const fn set_master(&mut self, val: Master)
Master mode select.
Sourcepub const fn loop_(&self) -> bool
pub const fn loop_(&self) -> bool
Loopback mode enable. Loopback mode applies only to Master mode, and connects transmit and receive data connected together to allow simple software testing.